/* drvTSCommands.c */

/***********************************************************************
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory, and the Regents of the University of
* California, as Operator of Los Alamos National Laboratory, and
* Berliner Elektronenspeicherring-Gesellschaft m.b.H. (BESSY).
* asynDriver is distributed subject to a Software License Agreement
* found in file LICENSE that is included with this distribution.
***********************************************************************/
/* Author: Marty Kraimer */

#include <stddef.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include <errno.h>
#include <time.h>

#include <epicsExport.h>
#include <epicsString.h>
#include <iocsh.h>
#include "drvTS.h"
#define epicsExportSharedSymbols


static const iocshFuncDef TSinitDef = {"TSinit",0,0};
static void TSinitCall(const iocshArgBuf * args) {
    TSinit();
}

static const iocshFuncDef TSreportDef = {"TSreport",0,0};
static void TSreportCall(const iocshArgBuf * args) {
    TSreport();
}

static const iocshArg TSconfigureArg0 = {"master", iocshArgInt};
static const iocshArg TSconfigureArg1 = {"sync_rate_sec", iocshArgInt};
static const iocshArg TSconfigureArg2 = {"clock_rate_hz", iocshArgInt};
static const iocshArg TSconfigureArg3 = {"master_port", iocshArgInt};
static const iocshArg TSconfigureArg4 = {"slave_port", iocshArgInt};
static const iocshArg TSconfigureArg5 =
    {"millisecond_request_time_out", iocshArgInt};
static const iocshArg TSconfigureArg6 = {"type", iocshArgInt};
static const iocshArg *const TSconfigureArgs[] = {
    &TSconfigureArg0,&TSconfigureArg1,&TSconfigureArg2,
    &TSconfigureArg3,&TSconfigureArg4,&TSconfigureArg5,
    &TSconfigureArg6};
static const iocshFuncDef TSconfigureDef = {"TSconfigure",7,TSconfigureArgs};
static void TSconfigureCall(const iocshArgBuf * args) {
    TSconfigure(args[0].ival,args[1].ival,args[2].ival,
                args[3].ival,args[4].ival,args[5].ival,
                args[6].ival);
}

static const iocshFuncDef TSsetClockFromUnixDef = {"TSsetClockFromUnix",0,0};
static void TSsetClockFromUnixCall(const iocshArgBuf * args) {
    TSsetClockFromUnix();
}

static const iocshArg TSsetSyncReportThresholdArg0 =
    {"syncMilliseconds", iocshArgInt};
static const iocshArg TSsetSyncReportThresholdArg1 =
    {"syncUnixMilliseconds", iocshArgInt};
static const iocshArg *const TSsetSyncReportThresholdArgs[] =
    {&TSsetSyncReportThresholdArg0,&TSsetSyncReportThresholdArg1};
static const iocshFuncDef TSsetSyncReportThresholdDef =
    {"TSsetSyncReportThreshold",2,TSsetSyncReportThresholdArgs};
static void TSsetSyncReportThresholdCall(const iocshArgBuf * args) {
    TSsetSyncReportThreshold(args[0].ival,args[1].ival);
}

static const iocshFuncDef TSprintRealTimeDef = {"TSprintRealTime",0,0};
static void TSprintRealTimeCall(const iocshArgBuf * args) {
    TSprintRealTime();
}

static const iocshArg TSprintTimeStampArg0 = {"eventNum",iocshArgInt};
static const iocshArg *const TSprintTimeStampArgs[] = {&TSprintTimeStampArg0};
static const iocshFuncDef TSprintTimeStampDef =
    {"TSprintTimeStamp",1,TSprintTimeStampArgs};
static void TSprintTimeStampCall(const iocshArgBuf * args) {
    TSprintTimeStamp(args[0].ival);
}

static const iocshFuncDef TSprintCurrentTimeDef = {"TSprintCurrentTime",0,0};
static void TSprintCurrentTimeCall(const iocshArgBuf * args) {
    TSprintCurrentTime();
}

static const iocshFuncDef TSprintUnixTimeDef = {"TSprintUnixTime",0,0};
static void TSprintUnixTimeCall(const iocshArgBuf * args) {
    TSprintUnixTime();
}

static const iocshFuncDef TSprintMasterTimeDef = {"TSprintMasterTime",0,0};
static void TSprintMasterTimeCall(const iocshArgBuf * args) {
    TSprintMasterTime();
}

static void drvTSRegister(void)
{
    static int firstTime = 1;
    if(!firstTime) return;
    firstTime = 0;
    iocshRegister(&TSinitDef,TSinitCall);
    iocshRegister(&TSreportDef,TSreportCall);
    iocshRegister(&TSconfigureDef,TSconfigureCall);
    iocshRegister(&TSsetClockFromUnixDef,TSsetClockFromUnixCall);
    iocshRegister(&TSsetSyncReportThresholdDef,TSsetSyncReportThresholdCall);
    iocshRegister(&TSprintRealTimeDef,TSprintRealTimeCall);
    iocshRegister(&TSprintTimeStampDef,TSprintTimeStampCall);
    iocshRegister(&TSprintCurrentTimeDef,TSprintCurrentTimeCall);
    iocshRegister(&TSprintUnixTimeDef,TSprintUnixTimeCall);
    iocshRegister(&TSprintMasterTimeDef,TSprintMasterTimeCall);
}
epicsExportRegistrar(drvTSRegister);
